[−][src]Enum toml::map::Entry
pub enum Entry<'a> {
Vacant(VacantEntry<'a>),
Occupied(OccupiedEntry<'a>),
}A view into a single entry in a map, which may either be vacant or occupied.
This enum is constructed from the entry method on Map.
Variants
Vacant(VacantEntry<'a>)A vacant Entry.
Occupied(OccupiedEntry<'a>)An occupied Entry.
Implementations
impl<'a> Entry<'a>[src][−]
pub fn key(&self) -> &String[src][−]
Returns a reference to this entry's key.
pub fn or_insert(self, default: Value) -> &'a mut Value[src][−]
Ensures a value is in the entry by inserting the default if empty, and returns a mutable reference to the value in the entry.
pub fn or_insert_with<F>(self, default: F) -> &'a mut Value where
F: FnOnce() -> Value, [src][−]
F: FnOnce() -> Value,
Ensures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.